@@ -18,17 +18,19 @@ class grep(BasePlugin):
     category = ["tools"]
     priority = 99
 
-    parameters = (
-        ("regex", "", True, "Regex to perform the grep against."),
-    )
+    parameters = (("regex", "", True, "Regex to perform the grep against."),)
 
     def __init__(self):
         BasePlugin.__init__(self)
         try:
             print(self.kbase["grep.regex"])
-            self.regex = re.compile(self.kbase["grep.regex"][0], re.MULTILINE | re.DOTALL)
+            self.regex = re.compile(
+                self.kbase["grep.regex"][0], re.MULTILINE | re.DOTALL
+            )
         except Exception:
-            raise FuzzExceptPluginBadParams("Incorrect regex or missing regex parameter.")
+            raise FuzzExceptPluginBadParams(
+                "Incorrect regex or missing regex parameter."
+            )
 
     def validate(self, fuzzresult):
         return True
